@@ -47,7 +47,7 @@
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
 
-#ifdef MAC_INTEGRATION
+#ifdef MAC_BUNDLE
 #  include <gtkosxapplication.h>
 #endif
 
@@ -166,13 +166,13 @@ build_package_paths (void)
   if (path)
     pixmaps_dir = g_strdup (path);
 
-#if defined (G_OS_WIN32) || (defined (MAC_INTEGRATION) && defined (MAC_BUNDLE))
+#if defined (G_OS_WIN32) || defined (MAC_BUNDLE)
   gchar *prefix;
 
 # ifdef G_OS_WIN32
   prefix = g_win32_get_package_installation_directory_of_module (NULL);
 
-# else // defined (MAC_INTEGRATION) && defined (MAC_BUNDLE)
+# else // defined (MAC_BUNDLE)
   prefix = quartz_application_get_resource_path ();
 
 # endif
@@ -505,7 +505,7 @@ glade_app_do_event (GdkEvent *event)
   /* As a slight optimization we could replace gtk_widget_get_ancestor()
    * with a custom function that only iterates trough parents with windows.
    */
-  if (widget && IS_GLADE_WIDGET_EVENT (event->type) &&
+  if (widget && GLADE_WIDGET_IS_EVENT (event->type) &&
       (layout = gtk_widget_get_ancestor (widget, GLADE_TYPE_DESIGN_LAYOUT)))
     return _glade_design_layout_do_event (GLADE_DESIGN_LAYOUT (layout), event);
 
