@@ -65,8 +65,8 @@
  *
  * Returns: the type function getter
  */
-static gchar *
-glade_util_compose_get_type_func (const gchar *name)
+gchar *
+_glade_util_compose_get_type_func (const gchar *name)
 {
   gchar *retval;
   GString *tmp;
@@ -118,23 +118,23 @@ glade_util_get_type_from_name (const gchar *name, gboolean have_func)
   GType type = 0;
   gchar *func_name = (gchar *) name;
 
+  if (g_once_init_enter (&allsymbols))
+    {
+      GModule *symbols = g_module_open (NULL, 0);
+      g_once_init_leave (&allsymbols, symbols);
+    }
+
   if ((type = g_type_from_name (name)) == 0 &&
       (have_func ||
-       (func_name = glade_util_compose_get_type_func (name)) != NULL))
+       (func_name = _glade_util_compose_get_type_func (name)) != NULL))
     {
-
-      if (!allsymbols)
-        allsymbols = g_module_open (NULL, 0);
-
       if (g_module_symbol (allsymbols, func_name, (gpointer) & get_type))
         {
           g_assert (get_type);
           type = get_type ();
         }
       else
-        {
-          g_warning (_("We could not find the symbol \"%s\""), func_name);
-        }
+        g_warning (_("We could not find the symbol \"%s\""), func_name);
 
       if (!have_func)
         g_free (func_name);
@@ -773,6 +773,20 @@ glade_util_find_iter_by_widget (GtkTreeModel *model,
   return NULL;
 }
 
+/**
+ * glade_util_list_objects_ref: (skip)
+ * @list: (transfer full): A #GList
+ *
+ * Add a reference to each GObject in the list.
+ */
+void
+glade_util_list_objects_ref (GList  *list)
+{
+  GList *l;
+  for (l = list; l; l = g_list_next (l))
+    g_object_ref (l->data);
+}
+
 /**
  * glade_util_purify_list: (skip)
  * @list: (transfer full): A #GList
