@@ -317,7 +317,7 @@ glade_gtk_label_set_property (GladeWidgetAdaptor *adaptor,
       if (!strcmp (id, "ellipsize"))
         glade_gtk_label_update_lines_sensitivity (object);
 
-      GWA_GET_CLASS (GTK_TYPE_WIDGET)->set_property (adaptor, object, id, value);
+      GLADE_WIDGET_ADAPTOR_GET_ADAPTOR_CLASS (GTK_TYPE_WIDGET)->set_property (adaptor, object, id, value);
     }
 }
 
@@ -397,7 +397,7 @@ glade_gtk_label_read_widget (GladeWidgetAdaptor *adaptor,
     return;
 
   /* First chain up and read in all the normal properties.. */
-  GWA_GET_CLASS (GTK_TYPE_WIDGET)->read_widget (adaptor, widget, node);
+  GLADE_WIDGET_ADAPTOR_GET_ADAPTOR_CLASS (GTK_TYPE_WIDGET)->read_widget (adaptor, widget, node);
 
   glade_gtk_label_read_attributes (widget, node);
 
@@ -481,7 +481,7 @@ glade_gtk_label_write_widget (GladeWidgetAdaptor *adaptor,
     return;
 
   /* First chain up and read in all the normal properties.. */
-  GWA_GET_CLASS (GTK_TYPE_WIDGET)->write_widget (adaptor, widget, context,
+  GLADE_WIDGET_ADAPTOR_GET_ADAPTOR_CLASS (GTK_TYPE_WIDGET)->write_widget (adaptor, widget, context,
                                                  node);
 
   attrs_node = glade_xml_node_new (context, GLADE_TAG_ATTRIBUTES);
@@ -524,7 +524,7 @@ glade_gtk_label_string_from_value (GladeWidgetAdaptor *adaptor,
       return str;
     }
   else
-    return GWA_GET_CLASS
+    return GLADE_WIDGET_ADAPTOR_GET_ADAPTOR_CLASS
         (GTK_TYPE_WIDGET)->string_from_value (adaptor, def, value);
 }
 
@@ -547,7 +547,7 @@ glade_gtk_label_create_eprop (GladeWidgetAdaptor *adaptor,
                             "use-command", use_command, NULL);
     }
   else
-    eprop = GWA_GET_CLASS
+    eprop = GLADE_WIDGET_ADAPTOR_GET_ADAPTOR_CLASS
         (GTK_TYPE_WIDGET)->create_eprop (adaptor, def, use_command);
   return eprop;
 }
@@ -561,7 +561,7 @@ glade_gtk_label_create_editable (GladeWidgetAdaptor *adaptor,
   if (type == GLADE_PAGE_GENERAL)
     editable = (GladeEditable *) glade_label_editor_new ();
   else
-    editable = GWA_GET_CLASS (GTK_TYPE_WIDGET)->create_editable (adaptor, type);
+    editable = GLADE_WIDGET_ADAPTOR_GET_ADAPTOR_CLASS (GTK_TYPE_WIDGET)->create_editable (adaptor, type);
 
   return editable;
 }
